﻿using System.Collections.Generic;
using System.Web.Mvc;
using System.Data;

using System.Linq;
using MvcContrib.Pagination;
using FizzWare.NBuilder;
using MvcContribExample.Models;

namespace MvcContribExample.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            var listaRandom = Builder<UsuariosModel>.CreateListOfSize(25).TheFirst(1)
                .With(x => x.nombre = "Jack")
                .And(x => x.apellido = "Fiallos")
                .And(x => x.deporte = "Baloncesto")
                .Build();

            DataTable data = new DataTable();
            data.Columns.Add("nombre", typeof(string));
            data.Columns.Add("apellido", typeof(string));
            data.Columns.Add("deporte", typeof(string));

            foreach (var item in listaRandom)
            {
                DataRow row = data.NewRow();
                row[0] = item.nombre;
                row[1] = item.apellido;
                row[2] = item.deporte;
                data.Rows.Add(row);
            }

            var resultado = (from DataRow row in data.Rows select new UsuariosModel(row["nombre"].ToString(), row["apellido"].ToString(), row["deporte"].ToString())).Skip(0).Take(5).ToList();
            ViewData["model"] = resultado;

            var model = new UsuariosModel();
            model.pageList = data.AsEnumerable().AsQueryable().AsPagination(1, 5);

            Session["datos"] = data;
            return View(model);
        }

        [HttpPost]
        public ActionResult Paginate(UsuariosModel model, int? page)
        {
            int pageSize = 5;

            int limite = (pageSize * ((page == null) ? 1 : (int)page));
            int inicio = limite - pageSize;

            DataTable data = (DataTable)Session["datos"];

            var resultado = (from DataRow row in data.Rows select new UsuariosModel(row["nombre"].ToString(), row["apellido"].ToString(), row["deporte"].ToString())).Skip(inicio).Take(pageSize).ToList();

            ViewData["model"] = resultado;
            model.pageList = data.AsEnumerable().AsQueryable().AsPagination((page == null) ? 1 : (int)page, pageSize);

            return View("index", model);
        }
    }
}
